#ifndef LLIST_DEFINED
#define LLIST_DEFINED

/* (C) 1995 Erik Troan
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "types.h"

struct Node
{
    struct Node * Next, * Prev;
    char Data[50000];
} ;

typedef struct LList
{
    struct Node * Top, * Bottom, * Curr;
    unsigned int Size, NumItems;
} LList, * LListPtr;

typedef struct Node * LLMarker;

void InitLL(LList * List, unsigned int Size);
void ClearLL(LList * List);
Boolean AddLL(LList * List, const void * Item);
Boolean AddTopLL(LList * List, const void * Item);
Boolean UpdateLL(LList * List, const void * Item);
void TopLL(LList * List);
void EndLL(LList * List);
Boolean NextLL(LList * List);
Boolean PrevLL(LList * List);
Boolean GetLL(LList * List, void * Item);
Boolean IterGetLL(LList * List, void * Item);
Boolean PastEndLL(LList * List);               /* False if past the borders */
Boolean PastTopLL(LList * List);
Boolean DeleteLL(LList * List);
Boolean AtEndLL(LList * List);
Boolean AtTopLL(LList * List);
LLMarker SavePosLL(LList * List);
void RestorePosLL(LList * List, LLMarker Save);
Boolean EmptyLL(LList * List);
void ConcatLL(LList * Left, LList * Right);
unsigned int NumItemsLL(LList * List);

#endif

